Crate geph4_binder_transport

Crate geph4_binder_transport 

Structs

BinderRequest
A binder request
BridgeDescriptor
Bridge descriptor
EncryptedBinderRequestData
Encrypted binder request data. Uses a crypto-box-like construction.
EncryptedBinderResponse
Encrypted binder response (encrypted Result)
ExitDescriptor
Exit descriptor
HttpClient
An HTTP-based BinderClient implementation, driven by ureq.
HttpServer
An HTTP-based BinderServer implementation. It uses async-h1 underneath, driven by an internal executor so that it exposes a synchronous interface.
MultiBinderClient
A BinderClient implementation wrapping multiple BinderClients.
SubscriptionInfo
Information about a user’s subscription
UserInfo
Information for a particular user

Enums

BinderError
Error type enumerating all that could go wrong needed: e.g. user does not exist, wrong password, etc.
BinderRequestData
Data for a binder request
BinderResponse
Binder response

Traits

BinderClient
Trait that all binder clients implement.
BinderServer
Trait that all binder transport servers implement.

Functions

encrypt_binder_response
Encrypts it to the reply key

Type Aliases

BinderResult
Either a response or a binder error